summaryrefslogtreecommitdiffstats
path: root/server
diff options
context:
space:
mode:
authorJonathon Jongsma <jjongsma@redhat.com>2015-11-13 10:29:12 -0600
committerFrediano Ziglio <fziglio@redhat.com>2015-11-16 12:45:03 +0000
commit1e8b2fe324b7d5afacc2652cffe22eab65f7b2c6 (patch)
tree1eb2dcc042dd835fb14d0adf2c342878792fad09 /server
parente49072492a9f08d2aa07e103fc8f77a8bb13a64f (diff)
downloadspice-1e8b2fe324b7d5afacc2652cffe22eab65f7b2c6.tar.gz
spice-1e8b2fe324b7d5afacc2652cffe22eab65f7b2c6.tar.xz
spice-1e8b2fe324b7d5afacc2652cffe22eab65f7b2c6.zip
worker: Rename current_clear() to current_remove_all()
Acked-by: Pavel Grunt <pgrunt@redhat.com>
Diffstat (limited to 'server')
-rw-r--r--server/red_worker.c16
1 files changed, 8 insertions, 8 deletions
diff --git a/server/red_worker.c b/server/red_worker.c
index 3d067c84..f8df8376 100644
--- a/server/red_worker.c
+++ b/server/red_worker.c
@@ -1050,7 +1050,7 @@ static inline void current_remove(RedWorker *worker, TreeItem *item)
}
}
-static void red_current_clear(RedWorker *worker, int surface_id)
+static void current_remove_all(RedWorker *worker, int surface_id)
{
RingItem *ring_item;
@@ -2844,10 +2844,10 @@ static inline void red_process_surface(RedWorker *worker, RedSurfaceCmd *surface
}
set_surface_release_info(&red_surface->destroy, surface->release_info, group_id);
red_handle_depends_on_target_surface(worker, surface_id);
/* note that red_handle_depends_on_target_surface must be called before red_current_clear.
otherwise "current" will hold items that other drawables may depend on, and then
- red_current_clear will remove them from the pipe. */
- red_current_clear(worker, surface_id);
+ current_remove_all will remove them from the pipe. */
+ current_remove_all(worker, surface_id);
red_clear_surface_drawables_from_pipes(worker, surface_id, FALSE);
red_surface_unref(worker, surface_id);
break;
@@ -3393,7 +3393,7 @@ static void red_current_flush(RedWorker *worker, int surface_id)
while (!ring_is_empty(&worker->surfaces[surface_id].current_list)) {
free_one_drawable(worker, FALSE);
}
- red_current_clear(worker, surface_id);
+ current_remove_all(worker, surface_id);
}
// adding the pipe item after pos. If pos == NULL, adding to head.
@@ -8819,10 +8819,10 @@ static inline void destroy_surface_wait(RedWorker *worker, int surface_id)
}
red_handle_depends_on_target_surface(worker, surface_id);
/* note that red_handle_depends_on_target_surface must be called before red_current_clear.
otherwise "current" will hold items that other drawables may depend on, and then
- red_current_clear will remove them from the pipe. */
- red_current_clear(worker, surface_id);
+ current_remove_all will remove them from the pipe. */
+ current_remove_all(worker, surface_id);
red_clear_surface_drawables_from_pipes(worker, surface_id, TRUE);
}
@@ -2844,10 +2844,10 @@ static inline void red_process_surface(RedWorker *worker, RedSurfaceCmd *surface
set_surface_release_info(&red_surface->destroy, surface->release_info, group_id);
red_handle_depends_on_target_surface(worker, surface_id);
- /* note that red_handle_depends_on_target_surface must be called before red_current_clear.
+ /* note that red_handle_depends_on_target_surface must be called before current_remove_all.
otherwise "current" will hold items that other drawables may depend on, and then
@@ -8819,10 +8819,10 @@ static inline void destroy_surface_wait(RedWorker *worker, int surface_id)
}
red_handle_depends_on_target_surface(worker, surface_id);
- /* note that red_handle_depends_on_target_surface must be called before red_current_clear.
+ /* note that red_handle_depends_on_target_surface must be called before current_remove_all.
otherwise "current" will hold items that other drawables may depend on, and then